==> ejc-cfs-impl-3.0.0-20201229.084913-67-sources.jar: com/ejianc/foundation/cfs/bean/CustomColumnEntity.java <==
package com.ejianc.foundation.cfs.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 自定义列
 * 
 * @author guoming
 *
 */
@TableName("ejc_cfs_column")
public class CustomColumnEntity extends BaseEntity {

	private static final long serialVersionUID = 3681529442997618286L;
	
	@TableField(value = "custom_table_id")
	private Long customTableId; //自定义表ID
	
	@TableField(value = "column_name")
	private String columnName; //列名
	
	@TableField(value = "property")
	private String property; //列属性值
	
	@TableField(value = "type")
	private String type; //类型（string、integer、long、date、boolean、decimal、refer、select）
	
	@TableField(value = "val")
	private String val; //类型值(refer时)
	
	@TableField(value = "sequence")
	private Integer sequence; //排序号

	public Long getCustomTableId() {
		return customTableId;
	}

	public void setCustomTableId(Long customTableId) {
		this.customTableId = customTableId;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getVal() {
		return val;
	}

	public void setVal(String val) {
		this.val = val;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}
	
	
}

==> ejc-cfs-impl-3.0.0-20240314.085926-189-sources.jar: com/ejianc/foundation/cfs/bean/CustomColumnEntity.java <==
package com.ejianc.foundation.cfs.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 自定义列
 * 
 * @author guoming
 *
 */
@TableName("ejc_cfs_column")
public class CustomColumnEntity extends BaseEntity {

	private static final long serialVersionUID = 3681529442997618286L;
	
	@TableField(value = "custom_table_id")
	private Long customTableId; //自定义表ID
	
	@TableField(value = "column_name")
	private String columnName; //列名
	
	@TableField(value = "property")
	private String property; //列属性值
	
	@TableField(value = "type")
	private String type; //类型（string、integer、long、date、boolean、decimal、refer、select）
	
	@TableField(value = "val")
	private String val; //类型值(refer时)
	
	@TableField(value = "sequence")
	private Integer sequence; //排序号

	@TableField(value = "uniqued")
	private Boolean uniqued; //数据唯一性校验

	public Long getCustomTableId() {
		return customTableId;
	}

	public void setCustomTableId(Long customTableId) {
		this.customTableId = customTableId;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getVal() {
		return val;
	}

	public void setVal(String val) {
		this.val = val;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public Boolean getUniqued() {
		return uniqued;
	}

	public void setUniqued(Boolean uniqued) {
		this.uniqued = uniqued;
	}
}
